@@ -1,13 +1,13 @@
 
 # -*- coding:utf-8 -*-
 
-from ..util import it,client,config
+from ..util import it,client,util
 from terminal import green
 from ..const import IMG_ID,INS_TYPE
+import json
 
 
-
-def create_cluster(clusterName, image=IMG_ID, type=INS_TYPE, nodes=1, description='', userData=None):
+def create_cluster(clusterName, image=IMG_ID, type=INS_TYPE, nodes=1, description='', userData=None, disk=None, show_json=False):
 
     cluster_desc = {}
     cluster_desc['Name'] = clusterName
@@ -28,12 +28,18 @@ def create_cluster(clusterName, image=IMG_ID, type=INS_TYPE, nodes=1, descriptio
         for item in userData:
            cluster_desc['UserData'][item.get('key')]=item.get('value')
 
-    #print(cluster_desc)
+    if disk:
+        if not cluster_desc.get('Configs'):
+            cluster_desc['Configs'] = {}
+        cluster_desc['Configs']['Disks']=disk
 
-    result = client.create_cluster(cluster_desc)
+    if show_json:
+        print(json.dumps(cluster_desc, indent=4))
+    else:
+        result = client.create_cluster(cluster_desc)
 
-    if result.StatusCode==201:
-        print(green('Cluster created: %s' % result.Id))
+        if result.StatusCode==201:
+            print(green('Cluster created: %s' % result.Id))
 
 
 
@@ -113,4 +119,8 @@ def trans_userData(userData):
     for item in items:
         arr = item.split(':',1)
         t.append( {'key': arr[0], 'value': arr[1] if len(arr)==2 else ''} )
-    return t
\ No newline at end of file
+    return t
+
+
+def trans_disk(disk):
+    return util.trans_disk(disk)
\ No newline at end of file
