@@ -3,7 +3,7 @@
 from ..util import client, oss_client, formater, list2table, result_cache, dag, util
 from terminal import bold, magenta, white, blue, green, red, yellow, confirm
 from oss2.exceptions import NoSuchKey,NoSuchBucket
-from ..const import CMD
+from ..const import CMD,WIN,PY2
 
 PROGRESS_LEN = 50
 
@@ -179,10 +179,20 @@ def getTaskDetail(jobId, taskName):
     print('%s' % bold(magenta('Task:')))
     list2table.print_table(arr, cols=['TaskName',('State', 'State', formater.get_job_state), 'Counts', 'StartTime', 'EndTime','Elapsed','Cluster'], show_no=False)
 
-
     # task description
     print('%s' % bold(magenta('Task Description:')))
 
+    # disks
+    if taskDesc.get('AutoCluster'):
+        disks = taskDesc['AutoCluster']['Configs']['Disks']
+        print(blue('Disks:'))
+        if disks.get('SystemDisk'):
+            print('  |--System Disk: %s (%s) %sGB' % ('/', blue(disks['SystemDisk']['Type']), disks['SystemDisk']['Size']))
+        if disks.get('DataDisk') and disks['DataDisk'].get('MountPoint'):
+            print('  |--Data Disk: %s (%s) %sGB' % (
+            disks['DataDisk']['MountPoint'], blue(disks['DataDisk']['Type']), disks['DataDisk']['Size']))
+    print('')
+
     command = formater.to_dict(taskDesc.Parameters.Command)
 
     print('%s: %s    %s: %s    %s: %s' %(  blue('Timeout'), taskDesc.Timeout, blue('MaxRetryCount'), taskDesc.MaxRetryCount, blue('WriteSupport'), taskDesc.WriteSupport, ))
@@ -293,10 +303,15 @@ def showLog(osspath, jobId, taskName, instanceId, logType):
     if isinstance(content, bytes):
         content = str(content.decode('utf8'))
 
-    if logType == 'stdout':
-        print(green(content))
+    if WIN and PY2:
+        print(content)
     else:
-        print(red(content))
+        if logType == 'stdout':
+            print(green(content))
+        else:
+            print(red(content))
+
+
     print(magenta('-'*46))
 
 
