@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 
 NAME = 'batchcompute-cli'
 
@@ -6,7 +7,7 @@ CMD = 'bcs'
 
 LOCALE_SUPPORTED = ['en', 'zh', 'zh_CN']
 
-VERSION = '1.2.0'
+VERSION = '1.2.6'
 
 
 IT = {
@@ -42,6 +43,7 @@ region = configObj.get('region')
 if region:
     REGION = region
 
+IS_GOD = configObj.get('god') or False
 
 
 try:
@@ -50,17 +52,19 @@ try:
     IMG_ID = configObj.get('defaultimage') or IMG[REGION]['default']
 
 except Exception as e:
-    INS_TYPE='ecs.s3.large'
     IT_DATA = IT['cn-qingdao']['data']
-    IMG_ID = IMG['cn-qingdao']['default']
+    INS_TYPE= configObj.get('defaulttype') or 'ecs.s3.large'
+    IMG_ID = configObj.get('defaultimage') or IMG['cn-qingdao']['default']
 
 
 
 import sys
 
+
 # Python 2 or Python 3 is in use.
 PY2 = sys.version_info[0] == 2
 PY3 = sys.version_info[0] == 3
+WIN = sys.platform == 'win32'
 
 # Definition of descriptor types.
 if PY2:
@@ -70,4 +74,20 @@ if PY2:
 if PY3:
     STRING = (str, bytes)
     NUMBER = int
-TIME = (int, str)
+
+
+# fix chinese view
+def get_local():
+    return codecs.lookup(locale.getpreferredencoding()).name
+if PY2:
+    import locale
+    import codecs
+    try:
+        reload(sys)
+        loc = get_local()
+        sys.setdefaultencoding(loc) # utf-8
+    except:
+        pass
+
+
+
